@@ -1,13 +1,13 @@
-import pyperclip
-import regex
 from rich import print
 from youtubesearchpython import SearchVideos, SearchPlaylists
 from PyInquirer import style_from_dict, Token, prompt
 from PyInquirer import Validator, ValidationError
 from halo import Halo
+import regex
 import re
 import sys
-
+import pyperclip
+#
 
 spinner = Halo(text='Searching', spinner='dots')
 
@@ -72,10 +72,9 @@ def search_query():
         }]
     answers = prompt(questions, style=style)
     if not answers:
-        print("baba")
-        
-    return answers
+        pass
 
+    return answers
 
 
 def search_video(query):
@@ -85,9 +84,8 @@ def search_video(query):
     final_data = data.result()
     if not final_data:
         spinner.stop()
-
         print("[bold red]  Something went wrong. Try another query or check network connenctivity[bold red]")
-        
+
     else:
         options = []
         for i in final_data['search_result']:
@@ -95,11 +93,8 @@ def search_video(query):
             temp_dict.update({'name': i['title'], 'value': i['link']})
             options.append(temp_dict)
         spinner.stop()
-    
 
         return options
- 
-
 
 
 def search_playlist(query):
@@ -109,17 +104,16 @@ def search_playlist(query):
     final_data = data.result()
     if not final_data:
         spinner.stop()
-
         print("[bold red]  Something went wrong. Try another query or check network connenctivity[/bold red]")
-        
-    else:   
+
+    else:
         options = []
         for i in final_data['search_result']:
             temp_dict = {}
             temp_dict.update({'name': i['title'], 'value': i['link']})
             options.append(temp_dict)
         spinner.stop()
-    
+
         return options
 
 
@@ -176,8 +170,7 @@ def start_1():
         }]
     ans1 = prompt(ques1, style=style)
     if not ans1:
-        print('hello')
-         
+        pass
 
     if ans1['source'] == 'video_search':
         query = ans1['query']
@@ -189,8 +182,8 @@ def start_1():
         }
         ans2 = prompt(ques2, style=style)
         if not ans2:
-            print("hi")
-            
+            pass
+
         return(ans2['url'])
 
     elif ans1['source'] == 'playlist_search':
@@ -203,8 +196,8 @@ def start_1():
         }
         ans2 = prompt(ques2, style=style)
         if not ans2:
-            print("mama")
-            
+            pass
+
         return(ans2['url'])
 
     elif ans1['source'] == 'manual':
